package JSV;

use 5.008005;
use strict;
use warnings;

our $VERSION = "0.07";

1;
__END__

=encoding utf-8

=head1 NAME

JSV - A perl implementation of JSON Schema (draft-04) validator

=head1 SYNOPSIS

=head1 DESCRIPTION

See e.g. L<JSV::Validator>

=head1 LICENSE

Copyright (C) zigorou.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=head1 AUTHOR

zigorou E<lt>zigorou@cpan.orgE<gt>

=cut

